Name:           imagej
Version:        1.53d
Release:        %mkrel 2
Summary:        Image Processing and Analysis in Java

Group:          Sciences/Computer science
License:        Public Domain
URL:            https://imagej.nih.gov/ij/index.html
Source0:        https://imagej.nih.gov/ij/download/src/ij153d-src.zip#/%{name}-%{version}.zip
Source1:        %{name}.desktop
Source2:        http://rsbweb.nih.gov/ij/macros/macros.zip
Source3:        http://rsb.info.nih.gov/ij/download/linux/unix-script.txt
Source4:        imagej.png
Source5:        imagej.1

# don't copy .class files
Patch0:         %{name}-1.53d-patch0.patch
# modify imagej.sh for fedora compatibility
# modify imagej.sh for OpenJDK >= 10 compatibility (mga#27225)
Patch1:         %{name}-1.50h-patch1.patch
BuildArch:      noarch

BuildRequires:  ant
BuildRequires:  java-devel
BuildRequires:  desktop-file-utils

# java-devel not java for plugins build
Requires:       java >= 1.6.0

%description
ImageJ is a public domain Java image processing program. It can display,
edit, analyze a wide variety of image data, including image sequences. Imagej
can be used for quantitative analysis of engineering and scientific image data.

%package javadoc
Summary:        Javadocs for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -c -n "%{name}-%{version}"
# patch build.xml
%patch0 -p0 -b .patch0
# unzip macros.zip
unzip -qq -u %{SOURCE2}
# erase binary and useless files
rm -rf macros/.FBC*
rm macros/build.xml
rm -rf __MACOSX
#get and patch unix-script.txt
cp %{SOURCE3} ./imagej.sh
%patch1 -p1 -b .patch1

find -name '*.class' -exec rm -f '{}' \;
find -name '*.jar' -exec rm -f '{}' \;

%build
cd source
%ant build javadocs
cd ..

%install

# install jar
mkdir -p %{buildroot}%{_javadir}
cp -p source/ij.jar   \
%{buildroot}%{_javadir}/%{name}.jar

# install javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -rp api  \
%{buildroot}%{_javadocdir}/%{name}

# install icon
mkdir -p %{buildroot}%{_datadir}/pixmaps
cp -p %{SOURCE4} %{buildroot}%{_datadir}/pixmaps

# install data files
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -p source/build/about.jpg %{buildroot}%{_datadir}/%{name}/about.jpg
cp -p source/build/IJ_Props.txt %{buildroot}%{_datadir}/%{name}/IJ_Props.txt

#install macros
chmod 644 macros/About\ Startup\ Macros 
find ./macros -name \*.txt -type f -exec chmod 644 {} \;
find ./macros -type d -exec chmod 755 {} \;
cp -rp macros %{buildroot}%{_datadir}/%{name}

#install luts
mkdir %{buildroot}%{_datadir}/%{name}/luts

# install script
mkdir -p %{buildroot}%{_bindir}
chmod +x imagej.sh
cp -p imagej.sh %{buildroot}%{_bindir}/%{name}

# directory for plugins
mkdir -p %{buildroot}%{_datadir}/%{name}/plugins
#cp source/plugins/JavaScriptEvaluator.source %%{buildroot}%%{_datadir}/%%{name}/plugins/JavaScriptEvaluator.java

# desktop file
desktop-file-install --vendor=""                     \
       --dir=%{buildroot}%{_datadir}/applications/   \
       %{SOURCE1}

# manpage
mkdir -p %{buildroot}%{_mandir}/man1
cp -p %{SOURCE5} %{buildroot}%{_mandir}/man1/

%files
%{_javadir}/*
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1.*
%doc source/aREADME.txt source/release-notes.html

%files javadoc
%{_javadocdir}/%{name}


%changelog
* Fri Sep 04 2020 daviddavid <daviddavid> 1.53d-2.mga8
+ Revision: 1621538
- fix imagej wrapper (the program that starts the Image GUI in Mageia)
  for Java version 10 or later. The wrapper made use of the -d64 and -d32
  options which have been deprecated for a while, did nothing, and were
  removed in OpenJDK 10.  See "Removal of Java Launcher's Data Model Options
  -d32 and -d64" on the openjdk-10 release notes (mga#27225)

* Sun Aug 30 2020 daviddavid <daviddavid> 1.53d-1.mga8
+ Revision: 1620109
- new version: 1.53d

* Sun Aug 30 2020 daviddavid <daviddavid> 1.52k-3.mga8
+ Revision: 1619997
- Rebuilt for JDK-11

* Fri Feb 14 2020 umeabot <umeabot> 1.52k-2.mga8
+ Revision: 1522870
- Mageia 8 Mass Rebuild

* Sun Feb 10 2019 daviddavid <daviddavid> 1.52k-1.mga7
+ Revision: 1364787
- new version: 1.52k

* Sun Feb 10 2019 daviddavid <daviddavid> 1.52j-1.mga7
+ Revision: 1364782
- new version: 1.52j

* Thu Sep 20 2018 umeabot <umeabot> 1.51w-2.mga7
+ Revision: 1278870
- Mageia 7 Mass Rebuild

* Tue Apr 03 2018 kekepower <kekepower> 1.51w-1.mga7
+ Revision: 1214811
- Update to version 1.51w

* Wed May 11 2016 daviddavid <daviddavid> 1.50h-1.mga6
+ Revision: 1012902
- Update to upstream release 1.50h

* Sun Feb 28 2016 umeabot <umeabot> 1.48e-2.mga6
+ Revision: 980464
- Mageia 6 Mass Rebuild

* Fri Jul 03 2015 daviddavid <daviddavid> 1.48e-1.mga6
+ Revision: 849716
- new version: 1.48e
- rename Patches
- add a png icon
- update desktop file
- update file list
- fix Group

* Wed Oct 15 2014 umeabot <umeabot> 1.45b-5.mga5
+ Revision: 747502
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.45b-4.mga5
+ Revision: 680484
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.45b-3.mga4
+ Revision: 505964
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 1.45b-2.mga3
+ Revision: 354289
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 20 2011 barjac <barjac> 1.45b-1.mga2
+ Revision: 169686
- Change to desktop file and spec
- imported package imagej


* Sat Nov 19 2011 Barry Jackson <zen25000[at]zen.co.uk> 1.45b-1.mga2
- Import imagej

* Wed Mar 09 2011 StM-CM-)phane TM-CM-)letchM-CM-)a <steletch@mandriva.org> 1.45b-2mdv2011.0
+ Revision: 643127
- Fix group tag for ImageJ and ImageJ-docs
- Add missing BR
- Fix group tag
- Update Mandriva specific informations
- Initial imageJ Mandriva package adaptated from Fedora package

